@@ -1,4 +1,8 @@
 import requests
+import os
+import sys
+sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), '..'))
+
 
 class PredictIssue():
     def __init__(self):
@@ -10,7 +14,7 @@ class PredictIssue():
         from dataneuronalp.config_variables import API_TOKEN
 
         try:
-            response = (requests.post("http://20.212.37.37/prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
+            response = (requests.post("http://20.212.37.37:4000/prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
             
             if response == "Error: Authorization failed":
                 status = "FAILURE"
@@ -47,7 +51,7 @@ class PredictIssue():
 
         else:
             try:
-                task_status = (requests.get("http://20.212.37.37/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
+                task_status = (requests.get("http://20.212.37.37:4000/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
                 status = task_status["state"]
 
                 if status == "AUTHORIZATION FAILURE":
